#
# spec file for package darktable
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           darktable
Version:        1.6.8
Release:        2.39
Url:            http://darktable.sourceforge.net
# darktable contains patented code that we cannot ship.  Therefore we use
# this script to remove the patented code before shipping it.
# Download the upstream tarball and invoke this script while in the
# tarball's directory:
# Originial Source:     https://github.com/darktable-org/darktable/releases/download/release-%{version}/darktable-%{version}tar.xz
# ./generate-tarball.sh 
Source0:        %name-%version-nopatents.tar.xz
Source1:        https://github.com/darktable-org/darktable/releases/download/release-1.6.0/darktable-usermanual.pdf
Source2:        README.openSUSE
Source3:        generate-tarball.sh
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  cmake
BuildRequires:  dbus-1-glib-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  intltool
BuildRequires:  lensfun-devel
BuildRequires:  libcolord-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libtiff-devel
BuildRequires:  libxslt
BuildRequires:  pkg-config
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(GraphicsMagick)
BuildRequires:  pkgconfig(OpenEXR)
BuildRequires:  pkgconfig(dri)
BuildRequires:  pkgconfig(exiv2)
BuildRequires:  pkgconfig(flickcurl)
BuildRequires:  pkgconfig(gnome-keyring-1)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libglade-2.0)
BuildRequires:  pkgconfig(libgphoto2)
BuildRequires:  pkgconfig(libopenjpeg)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(xrandr)
ExclusiveArch:  %ix86 x86_64

%if 0%{?suse_version} > 1220
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libwebp)
%endif

%if 0%{?suse_version} < 1315
BuildRequires:  libGraphicsMagick3
%endif

%if 0%{?suse_version} && (0%{?suse_version} > 1210 && 0%{?suse_version} < 1321)
BuildRequires:  lua-devel
%else
BuildRequires:  lua52-devel
%endif

%if 0%{?suse_version} > 1210
BuildRequires:  pkgconfig(libopenjpeg)
%endif

%if 0%{?suse_version} == 1210
BuildRequires:  xz
%endif
# needed for darktable black UI
%if 0%{?suse_version} == 1210
Requires:       gtk2-engines
%endif
%if 0%{?suse_version} > 1210
Requires:       gtk2-engine-clearlooks
%endif

Summary:        A virtual Lighttable and Darkroom
License:        GPL-3.0+
Group:          Productivity/Graphics/Viewers

%description
darktable is a virtual lighttable and darkroom for photographers: it manages
your digital negatives in a database and lets you view them through a zoomable
lighttable. it also enables you to develop raw images and enhance them.

%package doc
Summary:        A virtual Lighttable and Darkroom 
Group:          Productivity/Graphics/Viewers

%description doc
darktable is a virtual lighttable and darkroom for photographers: it manages
your digital negatives in a database and lets you view them through a zoomable
lighttable. it also enables you to develop raw images and enhance them.

This package provides the user manual in pdf format

%prep
%setup -q
chmod -x tools/create_control_svg.sh tools/purge_non_existing_images.sh tools/basecurve/* tools/noise/*

cp %{S:1} darktable-usermanual.pdf
cp %{S:2} .

%build
[ ! -d "build" ] && mkdir  build
cd build

export CFLAGS="%{optflags} -fno-strict-aliasing "
export CXXFLAGS="$CFLAGS"

cmake \
        -DCMAKE_INSTALL_PREFIX=%{_prefix} -DLIB_INSTALL=%{_lib} \
        -DCMAKE_BUILD_TYPE=Release \
        -DBINARY_PACKAGE_BUILD=1  \
        -DUSE_XMLLINT=OFF \
        -DUSE_SQUISH=OFF -DUSE_COLORD=ON -DBUILD_CMSTEST=On \
        ..
%__make %{_smp_mflags} VERBOSE=1

#%%__make -j 1 VERBOSE=1

%install
cd build
%make_install
cd ..
%suse_update_desktop_file darktable
find %{buildroot}%{_libdir} -name "*.la" -delete
%find_lang darktable

%__mkdir_p %{buildroot}%{_defaultdocdir}
%__mv %{buildroot}%{_datadir}/doc/darktable %{buildroot}%{_defaultdocdir}
cp %{S:2} %buildroot%_defaultdocdir/%name/.

%fdupes %{buildroot}

%files -f darktable.lang
%defattr(-,root,root)
%doc doc/AUTHORS doc/TODO doc/LICENSE  tools/purge_non_existing_images.sh tools/create_control_svg.sh tools/noise tools/basecurve README.openSUSE
%{_bindir}/darktable
%{_bindir}/darktable-cltest
%{_bindir}/darktable-cli
%{_bindir}/darktable-viewer
%{_bindir}/darktable-cmstest
%{_libdir}/darktable
%{_datadir}/applications/darktable.desktop
%{_datadir}/darktable
%dir %{_datadir}/appdata
%{_datadir}/appdata/darktable.appdata.xml
%{_datadir}/icons/hicolor/*/apps/darktable*
%{_mandir}/man1/darktable*.1.*

%files doc
%defattr(-,root,root)
%doc darktable-usermanual.pdf

%changelog
* Wed Sep 16 2015 fcrozat@suse.com
- Adapt BuildRequires for build on openSUSE Leap 42.1.
* Thu Jul 30 2015 mrueckert@suse.de
- update to 1.6.8
  - miscellaneous
  - clipping, santiy check for custom aspect ratios
  - read lensmodel from xmp
  - handle canon lens recognition special case
  - general cleanups
  - rawspeed:
  - Canon EOS M3
  - Canon EOS 5Ds (R)
  - Nikon 1 J5
  - Panasonic DMC-G7 (4:3 aspect ratio only)
  - Fujifilm X-T10
  - Pentax K-S2
  - Panasonic TZ71
  - Olympus TG-4
  - Leica VLUX1 4:3 aspect ratio mode
  - adobe_coeff:
  - Canon EOS M3
  - Canon EOS 5Ds (R)
  - Nikon 1 J5
  - Panasonic DMC-G7
  - Fujifilm X-T10
  - Pentax K-S2
  - Olympus TG-4
  - wb_presets:
  - Samsung NX500
  - Panasonic TZ71
  - noise profiles:
  - Sony ILCE-5100
  - Fujifilm HS50EXR
  - Canon EOS 5Ds R
- do not try to use lua 5.3 on TW
* Tue Jun 30 2015 mrueckert@suse.de
- Update to version 1.6.7 (boo #930683)
  - security
  - libraw CVE-2015-3885: fix integer overflow in ljpeg_start()
  - miscellaneous
  - improvements to facebook export
  - interpolation fixups
  - demosaic code cleanups
  - slideshow should handle very small images better
  - improve Olympus lens detection
  - various minor memory leak fixes
  - various other fixes
  - Pentax (K-x) DNG old embedded preview left over is now
    removed
  - modern OSX display profile handling
  - camera support
  - Nikon D7200 (both 12bit and 14bit compressed NEFs)
  - Nikon Coolpix P340
  - Canon EOS 750D
  - Canon EOS 760D
  - Canon EOS M2
  - Panasonic DMC-CM1
  - Panasonic DMC-GF7 (4:3 only)
  - Olympus XZ-10
  - Olympus SP570UZ
  - Samsung NX500
  - Fuji F600EXR
  - aspect ratios
  - Pansonic DMC-G5
  - Panasonic DMC-GM5
  - Panasonic FZ200
  - white balance presets
  - Nikon D7200
  - Nikon Coolpix P340
  - Panasonic DMC-GM1
  - Panasonic DMC-GM5
  - Olympus E-M10 (updated)
  - Olympus E-PL7
  - Olympus XZ-10
  - noise profiles
  - Canon Powershot G9
  - Sony A350
  - basecurves
  - Nikon D7200
  - Nikon D7000
  - Nikon D750
  - Nikon D90
  - translations updates: Catalan German Spanish Swedish
* Sat Apr 25 2015 mrueckert@suse.de
- Update to version 1.6.6
  - fix the Olympus E330 support (which was accidentally broken in
    1.6.4)
  - fix white balance reading for the Canon Powershot SX50 HS
  - white balance presets for RICOH GR
  - minor assorted bug fixes (masks, lens correction, profiled
    denoise, etc)
- remove unused cmake option from the cmdline:
  INSTALL_IOP_EXPERIMENTAL
* Fri Apr 17 2015 mrueckert@suse.de
- Update to version 1.6.4
  - general improvements:
  - major rawspeed update
  - facebook exporter update (first authentication usability
    should be much better now)
  - first run opencl benchmark to prevent opencl autoactivation
    if gpu is obviously slower than cpu
  - lensfun cornercase fixes
  - some mask cornercase fixes
  - zonesystem now updates it's gui when number of zones changes
  - spots iop updates
  - ui_last/gui_language should work more reliably now
  - internal lua updated from 5.2.3 to 5.2.4 (distro's typically
    use their own version of lua)
  - gcc 5 should build now
  - new camera support:
  - canon digital rebel (non european 300d)
  - nikon d5500 (experimental)
  - olympus e-m5 mark ii (experimental)
  - Samsung NX500 (experimental)
  - white balance presets:
  - sony a77 ii
  - fujiflim x-e2
  - olympus e-m5 mark ii
  - noise profiles:
  - canon 7d mark ii
  - updated translations: german french russian danish catalan
    japanese dutch
- drop 826152bc3564e74133680cc53e69e040d3663b47.patch included in
  release
* Mon Mar 23 2015 mrueckert@suse.de
- added 826152bc3564e74133680cc53e69e040d3663b47.patch:
  Backport from upstream to fix upstream issue #10370
  'Unable to work with Canon EOS Rebel images using darktable 1.6'
* Mon Mar  2 2015 toganm@opensuse.org
- Update to version 1.6.3
  * Changes:
    + Make camera import window transient
    + Allow soft limits on radius
    + Fix soft boundaries for black in exposure
    + Change order of the profile/intent combo in export dialog
    + Support read/write of chromaticities in EXR
    + Allow to default to :memory: db in config
    + Add mime handler for non-raw image file formats
    + Improved lens model name detection for Sony SAL lenses
  * Bug fixes:
    + Fix buffer overrun in SSE clipping loop for highlight handling
    + Prevent exporting when an invalid export/storage is selected
    + Hopefully last fix for aspect ratios in crop and rotate (#9942)
    + No tooltip when dragging in monochrome (#10319)
  * RAW support:
    + Panasonic LX100 (missing non-standard aspect ratio modes)
    + Panasonic TZ60
    + Panasonic FZ1000
    + KODAK EASYSHARE Z1015 IS
    + Canon 1DX (missing sRAW modes)
    + Canon A630 and SX110IS (CHDK RAW)
  * white balance presets
    + Panasonic FZ1000
    + Panasonic TZ60
    + Panasonic LX100
  * standard matrix
    + Canon Rebel T3 (non-european 1100D)
  * enhanced matrix
    + Nikon d750
  * noise profiles:
    + Canon EOS 1DX
* Sun Feb  1 2015 toganm@opensuse.org
- Update version 1.6.2
  * General improvements:
    + Better names for key accels (no more <Primary>)
    + Local gallery export limited to useful web formats
    (JPEG/PNG/WebP)
    + Add a way to control the brush size with keys
    + Default X-Trans Demosaic to markesteijn (single pass)
  * Bugfixes:
    + Fix IPTC Keyword reading for real
    + rawspeed: support short values in DNG ActiveArea
    + really disable parallel export
    + remove special characters from style export
    + Cropping aspect ratio fixes (#9942, #10265)
    + Some fixes to lua/masks/brushes
  * Camera support:
    + Pentax *ist DS
    + Pentax *ist DL2
    + Pentax K110D
    + Sony A7 II
    + Sony ILCE-3500
    + Nikon 1 S2
    + Olympus E-450
    + Panasonic LX1
    + Panasonic G3 (aspect ratio modes)
    + Samsung NX1 blackpoint finetuning
    + Fuji X-E1 blackpoint finetuning
  * White balance presets
    + 7D Mark II (updated)
    + Olympus E-M1
    + Sony A99
* Sat Jan 10 2015 toganm@opensuse.org
- Update to version 1.6.1
  * this is a point release which fixes a couple of minor issues in
    the recent feature release 1.6.0 (such as a crash with images
    greater than 134 megapixels).
* Mon Dec  8 2014 toganm@opensuse.org
- Update to version 1.6.0
  * general/misc:
    + high DPI monitor support
    + map view now allows to only show images from the current
    collection on the map
    + slideshow
    + darktable-cli now works without a running X server for use on
    headless systems
    + support for audio notes playback
    + sticky preview
    +  added the option to overwrite files when exporting to disk
    + crawler that syncs all xmp files on start
    + support huge images (> 32 bit pixel index). darktable can open
    26770x13385 TIFFs and should in theory be able to process arbitrary
    sized images. don't try this on a 32 bit system though!
    + lens iop presets are copy/pastable between different images
  * output
    + tiff read/write rewritten, works on 32-bit float now, supports
    compression
    + allow setting PPI for exported JPEGs, defaulting to 300
    pwstorage libsecret
    + use HTTPS when exporting to flickr
  * colour
    + color conversion speedup (openmp for lcms2 case)
    + add linear Rec2020 as a build-in profile
    + embedded icc profile support for png/tiff (read/write)
  * lua scripting:
    + copy, move, reset and delete images via lua
    + handle progress bars via lua
    + limited manipulation of libs an views UI via lua
    + import and export styles via lua
    + trigger lua when the grouping mode changes
    + trigger lua when the overlay mode changes
    + trigger lua when the active view changes
    + manipulate snapshots via lua
    + handle more types of preferences, including enums, directories
    and file names  lua API is now versioned: use
    darktable.configuration.check_version to check
    + lua API incompatibilities: darktable.modules has been removed,
    use darktable.new_format and darktable.new_storage to access the
    constructors
  * performance improvements
    + many speed improvements by adding sse code for image operations
    + make white balance work faster
    + make invert work faster
    + much faster exr export with optional compression (multicore
    support)
    + speedup of pfm writing
    + speedup of amaze. it is still slow but not as bad as it used to
    be
  * internal improvements:
    + module parameter introspection
    + clang/address-sanitizer/etc compiler warnings fixed
    + flip iop used for raw auto-orientation (simplifies code)
    + complete rawspeed migration for raw loading
  * bug fixes:
    + hdr bracketing fixes
    + masks cleanup and bugfixes
    + correct lens detection for compact cameras
    + avoid clipping in vignette, lowpass, shadows & highlights, a/b
    channels of colorcontrast and tonecurve
  * updated usermanual
  * lots of small performance improvements and code cleanup
  * Change source locations to reflect github project
* Wed Sep 17 2014 toganm@opensuse.org
- Add generate-tarball.sh as source file
* Tue Sep 16 2014 dmitry_r@opensuse.org
- Fix GraphicsMagick build dependencies
* Sat Apr 26 2014 fcrozat@suse.com
- update to version 1.4.2:
  + masks fixes
  + Explicitly try to load live view frames as JPEG
  + Silence calculator error messages
  + Translations updates
  + Aspect ratio modes for Panasonic DMC-G2
  + WB presets for Olympus E-PL5/E-PM2, Nikon D610, D3300
  + Various TIF fixes
  + Fix potential format string attacks via .po files
  + Add $(TITLE) to export variables
  + opencl: fix border handling in lens correction module
  + Experimental support and matrix for samsung nx30, nx1100,
    Olympus E-M10, Canon 1200d, Nikon D3300, D5300
  + Fix memory bugs spotted by Coverity
  + Various crash fixes
  + Update amaze code (SSE2 code)
  + Set lt position when changing image in dr with keys
  + Tonecurve: fix serious logical flaw.
  + Colorout: map shortkeys of gamut check/softproof to
    ctrl-g/ctrl-s
  + Fix crash when exporting to Picasa.
  + Noise profile: panasonic dmc-lx7
  + TIFF output: several fixes
  + Fix for Olympus focus distances
  + Tonecurve revamped
  + Try to limit network traffic of map view
* Sun Feb  9 2014 toganm@opensuse.org
- update to version 1.4.1
  * export: consistent names for output formats
  * export to disk: overwrite file option
  * grain plugin now allows smaller coarseness and will display
    coarseness values half of what they used to be, this is merely a
    cosmetic change, your images are unaffected.
  * some masks related fixes
  * some lua related fixes
  * tiff writer (32bit float, little endian output, configurable
    compression)
  * tiff reader
  * subtly nicer scrollbar behavior
  * theme loading cornercase fixups
  * shadow & highlight module improvements (should be less prone to
    artifacts when used on new images)
  * allow importing more than 1 style at a time
  * regression was fixed when building darktable against bleeding
    edge glibc
  * Sony A77V enhanced color matrix
  * Nikon D5100 updated white balance presets
  * Nikon 1 V2 noise profile (and by extension J3/AW1)
  * Nikon 1 J1 noise profile (and by extension V1/J2/S1)
  * Pentax K3 noise profile
  * experimental support for Panasonic DMC-LF1 (we still need
    samples for the nonstandard aspect ratios)
  * experimental support for SONY DSC-RX100M2
  * experimental support for SONY NEX-3N
  * still no Nikon D5300/D3300 support, we're still looking into
    that.
- Added pkgconfig(xandr) to build requires
* Wed Jan  1 2014 adrian@suse.de
- update to final version 1.4
- removed patches:
  * 0001-Fix-9720-Don-t-crash-when-kwallet-is-not-running.patch
* Mon Dec 16 2013 toganm@opensuse.org
- Fixes #bnc855442
  * added patches:
  - 0001-Fix-9720-Don-t-crash-when-kwallet-is-not-running.patch
* Sun Dec  1 2013 toganm@opensuse.org
- Update to release candidate 1.4~rc1
  * darktable now integrates a lua engine that allows writing scripts
    to make it easier to use with other image processing software.
    These scripts can be run when a particular event takes place (for
    example when a new image is imported) or when a particular keyboard
    shortcut is used. There are very few scripts available at this
    point but we expect the community to provide some more during the
    next release cycle.
  * darktable now include several kinds of drawn masks: brush,
    circle, ellipse, path and gradients
  * exporting in WebP format
  * serious speed enhancements of lighttable when using large
    colections
  * focus detection on lighttable
  * local cached copies of images for offline files
  * a few new blend mode like "HSV lightness", "HSV color", "Lab
    lightness" and "Lab color"
  * new modules "contrast brightness saturation", "color balance" and
    "color mapping" which replaces the now deprecated "color
    transfer" module
  * new histogram mode "waveform"
  * added a setting to automatically collapse modules to only have a
    single one expanded
  * better user experience for bauhaus sliders: the popup now has a
    blinking cursor to make possible text entry more discoverable
  * the text entry for bauhaus sliders and vimkeys' ":set" command
    can now evaluate mathematical expressions
  * many bug fixes and small improvements
  * a tool for measuring basecurves from a sample image
- Remove backported
  0001-Allow-compilation-with-colord-and-without-squish.patch
* Sun Nov 24 2013 toganm@opensuse.org
- Backported patch for colord compilation without squish
  0001-Allow-compilation-with-colord-and-without-squish.patch
* Tue Sep 10 2013 toganm@opensuse.org
- Update to version 1.2.3
  + Update to RawSpeed r570
  + Canon 70D (preliminary)
  + Olympus E-P5 (incl. preliminary Adobe Coeff.)
  + Samsung NX2000
  + Sony RX100m2
  + Sony SLT-A58 (updated)
  * White Balance Presets:
  + Sony NEX-5R
  + Sony SLT-A58
  + Nikon D3200 (updated)
  + Pentax K20D
  * Enhanced Color Matrix:
  + Pentax K20D
  * Noise Profiles:
  + Canon EOS 1100D == Canon EOS Rebel T3
  + Canon PowerShot S95
  + Canon PowerShot G11
  + Nikon Coolpix P330
  + Sony A580
  + Fuji X10
  + Pentax K20D
  * Fixes and improvements:
  + Increased maximum cache size to 8GB
  + OS X: fix Facebook uploads
  + Adjustments to default lowpass blur settings
  + Adjustments to dithering slider ranges
  + Metadata viewer: fix display of focal length: indicate unit
    and hide  if invalid.
  + Chromatic Aberrations: fix segfault for small buffers
  + Color pickers: fix various issues, e.g. #9482
  + More guides for Crop & Rotate
  + Improve light table usability: when viewing images in
    fullscreen wrap  around at line end when pressing right arrow
    key
  + Soften: massive speed improvements by using SSE and OpenMP
  + Deleting images from camera is not supported anymore for
    safety.
  + Exposure module now supports multiple instances
  + Support for custom meta data burn in (see commit
    6ac7ba055440aa27f79f0a67ac112799a0e7785e)
  + OpenCL support for nVidia GeForce GT330
  + PFM: load timestamp as date & time taken.
  + Fix bug prohibiting image rating by mouse
  + Update Picasa uploader: references Google+ now
  + Some fixes for memory leaks, deadlocks, background jobs
  + Fixes of on-screen handles for Crop&Rotate and GND modules
  + 0 bytes files will no longer be imported but ignored
* Tue Jun 25 2013 toganm@opensuse.org
- Update to version 1.2.2
  * updated rawspeed r553. Support for
    + Canon EOS 700D
    + Nikon Coolpix P330
  * New Olymbus base curve
  * Updated Adobe Coeffs
  * Enhanced color matrices:
    + Canon 700D (from Canon 650D)
    + Canon 100D (from Canon 650D)
  * Sony NEX-7
  * White balance presets:
    + Some updates from UFRaw
    + Canon 100D
    + Canon 700D
    + Sony SLT-A37
    + Nikon Coolpix P330
  * Noise profiles:
    + Canon EOS-M
    + Olympus E-600 (from: Olympus E-30)
    + Olympus E-620 (from: Olympus E-30)
    + Samsung WB2000
    + Sony A99v
    + Panasonic DMC-G10 iso 100
    + Nikon D60
  * Bug fixes:
    + 0 star rating working again
    + LT: ctrl+d duplicates per default now
    + Some fixes concerning locale handling
    + double click on film strip jumps to image
    + remember position in collections
    + ctrl+k jumps to previous collection
    + Blending parameters are preserved when module is deactivated
    + In full-preview (alt-1) ratings and labels are only applied to
    + image shown
    + Various OpenCL fixes, e.g. compilation on Mac OS X
    + libsquish compilation now optional
    + dr: deactivate interpolation at 200%% zoom
  * Removed backported patches:
  0001-thumbnail-compression-make-libsquish-optional
  0001-fixed-error-handling-for-broken-full-color-images.patch
* Thu Jun 20 2013 toganm@opensuse.org
-  Remove patented code from the source via
  generate--tarball.sh bnc#824484
  * added backported patch from git master
    0001-thumbnail-compression-make-libsquish-optional
  * Remove pkgconfig(colord) from Build Requires
  Because compression code is disabled previous cache will not
  work. Removing  ~/.cache/darktable/mipmaps is necessary
* Mon Jun 10 2013 toganm@opensuse.org
- added backported patch from git master
  0001-fixed-error-handling-for-broken-full-color-images.patch
  fixes bnc#823114
* Sun May 26 2013 toganm@opensuse.org
- Update to release 1.2.1
  * New translation: Danish
  * Some translations have been removed from the release due to
    missing strings
  * New noise profiles
    + Canon EOS 450D / Kiss X2
    + Canon EOS 1100D / REBEL T3
    + Canon EOS 1D Mark II
    + Canon EOS 1D Mark III
    + All Canon Model names are now recognized, e.g. Canon EOS 350D
    and Canon EOS 350D DIGITAL and Canon EOS DIGITAL REBEL XT and
    Canon EOS Kiss Digital N point to the same camera.
    + Olympus E-520
    + Olympus E-1
    + Olympus E-3
    + Olympus E-P2
    + Pentax K-30
    + Panasonic GH-2
    + Panasonic DMZ-FZ18
    + Additional data for Pentax K-5 II
    + Nikon D7100
    + Nikon D5200
    + Sony A57
  * White balances, color matrices
    + Fix issues with different camera model names for various Canon
    cameras (see above)
    + White balance for Panasonic DMC-GH2
    + Updates whitebalance list with the latest version of UFRaw's cvs version
    + Whitebalances for Samsung NX5, NX10, NX11 (copied from NX100)
  * Bugfixes
    + new RawSpeed version r537
    + Compatible with openEXR 2.0
    + Facebook export now allows HQ images (up to 2048px)
    + Blend mode "vividlight" should work for NaNs
    + Fix compile issues for OpenBSD
    + Whitebalance is now relative to daylight, not to camera white
    balance (this will not change any processing you have done,
    only the values displayed will differ)
    + Now importing folder via key accelerator is supported.
    + Only one temperature slider in white balance
    + Some fixes to the zoom behaviour in darkroom mode
    + New lensfun geometries now supported (with lensfun >= 0.2.7)
    + More coherent bauhaus UI for the split toning module
    + The color transfer module is now marked as deprecated. Will be
    superseeded by color mapping in the next major release.
    + Fix some possible deadlocks, memory leaks and null pointer dereferences
    + Status message in top bar should be updated more frequently now
    + Some more elaborate status messages if lens/camera not found in the
    lens correction module, if export failed
    + Option for parallel export threads removed from config, too dangerous
    + Option for thumbnail cache now specified in MB
    + Updated purge_non_existing_images.sh script
    + CLI option -d nan gives per-module output of NaN values
    + Some minor renamings, typo fixings...
- Drop 0001--OpenEXR-2.0-fixes.patch since fixed upstream
* Fri Apr 26 2013 mrueckert@suse.de
- First set CFLAGS and then CXXFLAGS. Sometimes we need to set
  flags in CXXFLAGS that are not valid CFLAGS.
* Tue Apr 23 2013 toganm@opensuse.org
- Fix factory build with OpenEXR-2.0
  added 0001-OpenEXR-2.0-fixes.patch
* Sat Apr  6 2013 toganm@opensuse.org
- Update to release 1.2
- removed
  darktable-1.2.x_update_to_4b856e6ec99035d5a1041db73e2339000d395aa0.patch
  as it is now included.
- When possible use pkgconfig hence:
  instead of libopenjgeg-devel  used  pkgconfig(libopenjpeg)
  instead of GraphicsMagick-devel used pkgconfig(GraphicsMagick)
- If build is for 12.1 then require gtk2-engines
* Thu Apr  4 2013 mrueckert@suse.de
- added darktable-1.2.x_update_to_4b856e6ec99035d5a1041db73e2339000d395aa0.patch:
  update to HEAD (4b856e6ec99035d5a1041db73e2339000d395aa0)
  - adobe_coeff: Nikon Coolpix A same as D7000
  - fix-crash-lr-import:
    Proactive fix to avoid a crash trying to dereference a null
    pointer.  If node stEvt:softwareAgent not found, skip as not a
    lightroom xmp.
  - don't crash on malformatted TIFF file
    In case a file was alraedy rejected by GraphicsMagick, it's not
    a good idea to try open it with our handmade imageio routines
    like TIFFOpen().  Let's take GraphicsMagick as a last resort if
    available.
  - usermanual: add missing file lighttable_directory.png
  - Fix: snapshot + gnd, cliping, ... #9329
  - Upgraded and reviewed Spanish translation
    I have fully reviewed the Spanish translation, fixing typos,
    improving grammar and the language used.
  - denoiseprofile: really fix legacy_params
  - denoiseprofile: get param "mode" right when converting params
    from version 2 to 3 fix: denoiseprofile: crash when trying to
    update presets/styles from version 2 to 3 do not try to find
    autodetection for them - would probably be not useful and is
    impossible anyway
  - Merge pull request #206 from bluesceada/denoise-copy-autodetect
    denoiseprofile: copy "profile autodetected" correctly + fix:
    display "found match" also for first profile
  - noise profile: canon eos 1d iv by rene weiss
  - denoiseprofile: only use a[0] = -1.0 to signal autodetection,
    and don't use epsilon for comparisons
  - denoiseprofile: make it possible to copy the information "this
    profile was set automatically" across images with different ISO
    and camera vendor
  - fix: denoiseprofile: also show "found match:" instead of the
    profile name for index 0
  - Preliminary update of the Russian translation
  - Merge branch 'fix-clipping-aspect'
  * fix-clipping-aspect:
    Fix aspect ratio computation.
    It cannot happen in legacy_params() as at this point the size
    of the image is not yet known. We then use a deferred
    circuitry to handle this at the right point in the code.
    Fixes #9320.
  - [l10n] Swedish update
* Thu Apr  4 2013 mrueckert@suse.de
- update to release 1.2.rc2
  - the changes on top of rc1 are minor, some details:
  - fixed a spurious crash/deadlock when switching images in
    filmstrip mode
  - fixed a couple of exif strings for profiled denoising
  - fixed gcc 4.8.0 build
  - new noise profiles
  - fixed gphoto 2.5 issues
  - updated translations
  - updated user manual!
- additional changes from 1.2.rc1
  - profiled denoising: adapt to the properties of your camera's
    sensor (72 cameras already profiled for you).
  - lightroom import: convert some basic edits from your lightroom
    collection to darktable operations.
  - multi instance support: duplicate your modules and apply them
    more than one time with different settings.
  - improved usability for distorting modules (streamline spot
    removal in the presence of crop/rotate for example).
  - selective copy/paste of image processing.
  - new more intuitive keystone correction tool.
  - jpeg2000 support.
  - graphics magick import (support virtually all input image
    formats).
  - much faster thumbnail loading (if you can live with crappy
    embedded thumbnails).
  - incredibly lengthy list of small bug fixes, performance
    enhancements, and usability improvements.
  - new camera support (decode and color matrices).
  - dithering against banding.
  - sharper thumbnails in lighttable mode.
  - new oauth2 based picasa uploader.
  - and the final release 1.2 will contain a thoroughly overhauled
    user manual, proof read by natives (thanks heaps guys!).
- removed 0001-Fix-svg-uses-premultiplied-alpha-we-didn-t-respect-t.patch
  included upstream
- added BuildRequires for GraphicsMagick and openjpeg
* Sun Mar 17 2013 fcrozat@suse.com
- Add gtk2-engine-clearlooks as Requires, needed for darktable
  black theme.
* Sun Mar 10 2013 toganm@opensuse.org
- Update to release 1.1.4 This is bugfix release no new features
  are introduced.
  * Fix tooltip style definition in darktable.gtkrc.
  * colorspaces: avoid trademark issues
  * colorspaces: workaround horrible brokenness of some printshops
  * colorspaces: actually cprt is a required icc tag
  * thumbs: use mip always > image size, not closest.
  * wb_presets: Nikon D3200 (stolen from UFRaw)
  * wb_presets: SONY SLT-A77V
  * wb_presets: Panasonic DMC-G5 (thanks to thouks)
  * wb_presets: Pentax K-5 II s (thanks to Jack Bowling)
  * wb_presets: Nikon D800(E) update
  * rawspeed: minor fix for LX7 in 3:2 mode
  * rawspeed: support Panasonic DMC-LX7 16:9 and 1:1 aspect ratio modes
  * rawspeed: support Panasonic DMC-LX7 3:2 aspect ratio mode
  * rawspeed: Preliminary support for the PENTAX K-5 II s
  * rawspeed: added Panasonic DMC-G5 1:1/16:9 modes
  * rawspeed: Nikon 1 S1 support
  * rawspeed: Nikon 1 J3 support
  * rawspeed: Nikon Coolpix P7100 blackpoint fix (thanks to nesthib)
  * Fix base curve presets for Canon on Spanish locale
  * Fix #9205: Read metadata from non-dt XMPs
  * blend: fix edge case in color blend mode
  * redraw: remove now obsolete flood stopping.
  * redraw: allow more redraws per second.
  * redraw signal: simplify the locking logic somewhat.
  * pack blendif settings a little bit closer in GUI
  * cache: have full buffers according to potentially exporting  threads
  * lens correction: fix for #9270
  * opencl: work around a bug in some OpenCL drivers
  * exif: return correct buffer length, patch by wolfgang goetz
  * match leica basecurve less selectively
  * Olympus E-M5 enhanced matrix with help from Frederic Crozat
  * ICC profile handling: catch certain mal-formatted profiles
- Added 0001-Fix-svg-uses-premultiplied-alpha-we-didn-t-respect-t.patch
- Remove 0001-Olympus-E-M5-enhanced-matrix.patch as it's upstreamed
* Sun Feb 10 2013 fcrozat@suse.com
- Add 0001-Olympus-E-M5-enhanced-matrix.patch: Enhanced matrix for
  Olympus OM-D E-M5.
* Sat Feb  9 2013 toganm@opensuse.org
- Update to release 1.13
  * fixes:
    + check (on build) if glib 2.28 or higher is present
    + don't sanatize exif when creating hdr dngs
    + colorpicker now disappears immediately when disabling it
    + lens correction now uses loose lens matching (ivan tarozzi)
    + konica minolta dynax 5d rotation fix
    + removed an outdated assertion which could cause a crash in rare
    cases
    + don't crash when loading half-corrupted xmp's
    + don't crash when an imported file contains incomplete gps
    information
    + libjpeg-turbo workaround (klaus post)
  * camera support:
    + preliminary support for the new nikon d5200
  * white balance presets:
    + sony alpha 700 (update to firmware v4)
    + sony alpha 230 (new)
    + canon eos 650d (new)
    + canon eos rebel t2i (fixed)
    + canon eos m (fixed)
  * enhanced color rendition:
    + konica minolta dynax 5d (wolfgang kuehnel)
    + sony nex 3 (wolfgang kuehnel)
    + sony alpha 230 (wolfgang kuehnel)
    + sony rx100 (josef wells)
- For openSUSE 12.1 added xz to buildrequires
* Sun Jan 13 2013 toganm@opensuse.org
- Update to release 1.1.2
  * darktable 1.1.2 is mostly a camera support update and bugfix
    release:
  - fix export resolution rounding issue (as in previous version it
    could be off-by-one)
  - correctly set output dimension in exif instead of passing the raw
    resolution verbatim
  - local average green eq was fixed (it now works on high iso images
    as well, and should no longer produce hot pixels)
  - use ordered arrays in xmp files
  - disable export parallelism for flickr/picasa export
  - don't enter tethering mode when there is no camera attached (this
    made darktable look asif it was hung, even though that wasn't the
    case)
  - bring back the pin for map thumbnails
  - improved tiff support
  - vignetting now has a dithering option (to mitigate occasional
    banding)
  - read nikon subject distance properly
  - assorted freebsd fixes
  - various opencl fixes
  - usermanual updates
  * Support for the following camera's with either preliminarily added
    or updated:
  - canon eos 6d
  - canon powershot s110
  - canon powershot g15
  - canon powershot sx50 hs
  - nikon 1 v2
  - nikon d600
  - nikon coolpix p7700
  - olympus e pl5
  - olympus e pm2
  - olympus xz 2
  - panasonic dmc gh3
  - panasonic dmc lx7
  - pentax k5ii
  - samsung ex2f
  - sony rx1
  - sony nex 6
  - sony slt a99
  - sony nex c3 blackpoint/greenshift fix
  * white balance preset updates:
  - canon eos 550d
  - canon eos 5d mark iii
  - olympus xz 1
  - sony nex c3
  - sony slt a57
  - sony nex 5n
  - panasonic dmc-gh3
* Sun Dec  9 2012 toganm@opensuse.org
- Update to release 1.1.1
  * minor reordering of lighttable mode modules (geotagging, keywords
    and recent collections)
  * cleaned up the default visible plugins when first starting
    darktable
  * in most cases raw files will now show thumbnails in the import
    dialog (thanks to Mattias Eriksson)
  * a curve related crash was fixed (#9906 thanks to James C.
    McPherson)
  * comma seperated tags should work everywhere now (#9006 thanks to
    Tobias Ellinghaus)
  * Ulrich pegelow fixed a huge amount of OpenCL related issues,
    particularly for AMD GPUs
  * we now deal better with hybrid GPU machines (#9074 by Ulrich
  Pegelow)
  * a deadlock in the lens correction module was fixed (#9106 thanks to
    Ulrich Pegelow)
  * we don't delete module presets when cancelling the dialog anymore
    (#9108 thanks to Tobias Ellinghaus)
  * we now have better default memory usage settings (which are set
    upon starting darktable the first time)
  * initial support for SONY NEX 5R
  * preliminary/experimental Canon EOS 6D and Sony RX1 support (future
    changes for these camera's may (for the time being) retroactively
    affect your images)
  * Canon EOS 6D white balance presets (thanks to no_maam_)
  * lots of updates for the usermanual (make sure you download a new
    copy)
- Subpackage the user manual
- enable darktable-viewer by adding sdl to buildrequires
* Tue Nov 27 2012 toganm@opensuse.org
- Update to release 1.1
  * general
    + new camera support, new whitebalance presets, etc., including
    canon eos m support and samsung nx fix
    + similarity matching search for images that look alike.
    + geotagging, complete with map view
    + a lot of bugfixes (mainly thanks to ulrich for his meticulous
    work)
    + facebook exporter (for those who have an account there)
  * ui
    + reworked the much hated `more plugins' widget
    + image grouping:
    + command line interface!
    + tone and base curves got a new user interface to better
    support fine grained workflow
    + visually low-profile controls with finetuning:
    + color correction module got a GUI update since the blog post
    (two circles indicating shadows and highlights instead of the
    quad).
    + live view for tethered shooting!
  * darkroom
    + extensive use of edge-aware filtering techniques to suppress
    noise, halos and ringing all around darktable:
    + conditional blending, and a lot of goodies around it!
    + magenta highlights: high-contrast edges to overexposed areas
    (should get rid of purple highlights on tiny water waves and
    purple fringes around tree leaves for example)
    + much improved sharpness for both export and darkroom view,
    especially for downsampled images and if you use lens
    corrections or rotations/perspective corrections. check the new
    options in the preferences dialog, also one more than mentioned
    in the blog ("demosaicing for zoomed out darkroom mode" to
    trade performance for even more sharpness):
  * color management
    + improved per-screen color management (should reload the
    screen profile automatically)
    + more compatible embedded color profiles (should fix problems
    on windows viewing our images, if that matters) read embedded
    color profiles from jpg
  * opencl
    + most of our modules now can take advantage of your computer's
    gpu power
    + caching for compiled opencl kernels (even in case the driver
    doesn't do it) for faster startup times
  * translations
    + two new translations (both portuguese.. ;) )
    + well translated: cs de es fr it ja nl pl pt_BR pt_PT sv
    + half translated: ca fi gl ro ru sq th zh_CN
- Packaging related :
  * Provide the pdf documentation
  * Remove backported patches as they are part of the package now
    + rsvg_cairo.patch
    + update-curves.patch
  * provide tool to work with database cleanup
    purge_non_existing_images.sh (placed in documentation
    directory)
  * where possible use pkgconfig variables for buildrequires
* Tue Oct  9 2012 toganm@opensuse.org
- Add rsvg_cairo.patch: Fixes Build for factory because of deprecated
  use of  librsvg (from git)
* Sun Aug  5 2012 fcrozat@suse.com
- Add update-curves.patch: add additional basecurves for Olympus
  E-M5 and EOS 5D Mark II/III and Nikon Dxxxx (from git)
* Tue Jul 24 2012 toganm@opensuse.org
- Update to release 1.0.5
  + Update to RawSpeed r438
  + Update to LibRaw 0.14.7
  + White balance presets for Nikon Coolpix P7100 and Panasonic GF3
  + White balance preset updates for Canon EOS 7D, Canon EOS 350D
  + Standard Color Matrices for Canon EOS 650D, Canon EOS 5D Mark
    III, Canon EOS 1D X, Canon PowerShot G1 X, Canon PowerShot SX220,
    Nikon D3200, Nikon D4, Nikon D800, Olympus E-M5, Panasonic GF5,
    Sony SLT-A37/A57, Leica X1/X2, Sony DSC-RX100
  + A few memory leaks were resolved
  + A few generic bugs were resolved
- use -DLENSFUN_INCLUDE_DIR to fix finding lensfun.h
* Thu Jun 14 2012 toganm@opensuse.org
- Disable build for powerppc as darktable requires sse instructions
* Mon Jun  4 2012 toganm@opensuse.org
- Enabled all plugins
* Sun Jun  3 2012 meissner@suse.com
- Update to release 1.0.4
  No upstream changelog, but various improvements, translation updates
  and bugfixes.
* Sat Apr 28 2012 toganm@opensuse.org
- Update to release 1.0.3
  + Usability improvements:
  * Filmstrip centers on selected image
  + Behavioral changes:
  * Improved (hierarchical) tag export for flickr and friends
  + Camera support:
  * Improved Sony NEX-7 support
  * Initial camera support for Nikon D800 and Sony SLT-A57
  * White balance updates for Canon EOS Rebel T3, Olympus E-5 & Nikon
    D800
  + Various:
  * New subtle denoise preset for equalizer
  * Various build fixes
  * Numerous other fixes
* Thu Mar 15 2012 toganm@opensuse.org
- Upgrade to release 1.0
  + new cameras supported
  * Leica M9
  * NX100/NX5/NX10/NX11
  * Panasonic DMC-GX1
  * Pentax K-r
  * Canon Powershot S100
  * Olympus XZ-1
  * Olympus E-P3
  * Sony DSLR A330
  * Sony NEX-5N
  * Canon EOS 1000D
  * Canon EOS 600D
  * Sony Alpha 390
  * Fuji Finepix HS20EXR
  + new and updated translations (we now have chinese!)
  + new image cache
  * faster concurrent access and insertion
  * reduces needed memory
  * more thumbnails stored on disk
  * read embedded jpegs for creating thumbnails (faster folder
    import)
  + increased general speed on sqlite3 (journaled, pagesize
    optimizations)
  + reworked, modular ui
  + keyboard shortcuts support - key accelerators (GSoC)
  + quicktool bar: exposure, presets and styles
  + new color picker
  + web gallery export now with next/prev buttons per image
  + removed gconf: not used anymore, we have our own backend
  + bugfixes
  + there have been issues with memory on 32-bit systems. seems to
    be okay currently, but something to keep in mind. use 64-bits
    if you can
* Tue Feb 28 2012 fcrozat@suse.com
- Add darktable-fix-deprecation.patch to fix glib deprecation.
* Tue Nov  8 2011 toganm@opensuse.org
- Upgrade to release 0.9.3:
  + sse optimizations
  * non-local means
  * graduated density
  * velvia
  * color management
  * equalizer
  * zone system
  + updated translations
  * ru,fr,es,ja,it,sq,pl,nl,de
  + more presets
  * split toning
  * tone curve
  * equalizer
  * color zones
  + lots of bugfixes
  * tiling code (low mem/opencl)
  * gcc 4.6 compat
  + updates
  * libraw 0.14b2
  * rawspeed r379
  as well as more basecurves and color matrices.
- added Mesa-devel to BuildRequires
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
* Tue Sep 13 2011 toganm@opensuse.org
- Added dbus-1-glib-devel to BuildRequires
* Sat Sep  3 2011 toganm@opensuse.org
- Update to bugfix release 0.9.2:
  + there are no new features, just
  * updated translations
  * tiling for memory hungry operations and as workaround for old
    opencl 1.0 drivers
  * new color matrices and white balance presets
  * a lot of stability issues have been resolved
  * a lot of performance improvements (more sse code, better
    opencl code)
  + Removed 0001-Remove-dependancy-on-git.patch
* Tue Jul 26 2011 toganm@opensuse.org
- Updated to bugfix release 0.9.1
  + new rawspeed, dcraw, libraw
  + fixed various segfaults and deadlocks
  + the pipeline is now more real HDR (no more gamut clipping in
    between)
  + fixed a nasty bug which could cause complete loss of history
    for an image
  + darktable-faster now plays nicely with darktablerc (non-gconf)
  + lots of opencl improvements
  + updated translations
  + second part of our GSoC: customizable keyboard shortcuts!
* Tue Jul  5 2011 toganm@opensuse.org
-Release 0.9:
    + run-time switchable opencl to exploit all the power of your GPU
    whenever you decide to install the driver
    + many new plugins, including a spot removal tool, better denoising
    (on raw pixels and non-local means) and many more
    + blend operations, overlay your plugin only 20 percent if you want
    + spot removal tool
    + low light vision tool
    + non-local-means denoising (relatively fast for nlmeans, but still
    slow)
    + first part of the google summer of code project
    already merged
    + framing plugin (adds postcard borders to match
    given aspect ratio)
    + tonemapping a lot faster now (probably the fastest high-dimensional
    bilateral filter)
    + changed images come with the darktable|changed tag
- removed darktable-08 related patches as they are now in the upstream
- use RPM optflags
* Fri Jun 17 2011 fcrozat@suse.com
- Add darktable-0.8-unused_variables.patch and
  darktable-0.8-clean_up_set_but_unused_variables.patch to fix
  build with gcc 4.6
- Add darktable-0.8-default_generic_optimizations.patch and
  darktable-0.8-binary_package_build.patch: don't optimize build
  for build system.
- Ensure package is build with debuginfo.
* Fri Jun 10 2011 fcrozat@suse.com
- Add libflickcurl-devel BuildRequires to get Flickr upload
  support.
* Thu Mar  3 2011 toganm@opensuse.org
- Fix building for x86_64
* Wed Feb 23 2011 fcrozat@novell.com
- Release 0.8:
  + much faster image loading due to rawspeed, an awesome new
    library by klaus post @rawstudio
  + lots of performance improvements in our caches and pixel
    pipelines (together with the above like 5x--10x)
  + gpu computing using opencl (for graphics boards that support
    it) for a lot of common plugins, to give a huge performance
    boost
  + overhauled collection plugin for more flexible image
    collections
  + metadata editor (set author and copyright information etc)
  + fast demosaicing now done on roi and in floating point
  + HDR bracketing and tone mapping (somewhat experimental)
  + flickr upload
  + lots of new color matrices and white balance presets
  + lots of bugfixes
  + Updated translations
* Mon Dec 13 2010 fcrozat@novell.com
- Release 0.7.1 :
  * some more white balance presets
  * layout fixes for overlong profile names
  * styles now actually work
* Tue Nov 23 2010 bitshuffler@opensuse.org
- Update to 0.7.
* Wed Sep  1 2010 bitshuffler@opensuse.org
- Initial package
